;; Generated package description from posframe.el  -*- no-byte-compile: t -*-
(define-package "posframe" "1.3.3.0.20230212.80826" "Pop a posframe (just a frame) at point" '((emacs "26.1")) :commit "06b939cfb06168782fc378043ff35bd7fec203b8" :authors '(("Feng Shu" . "tumashu@163.com")) :maintainer '("Feng Shu" . "tumashu@163.com") :keywords '("convenience" "tooltip") :url "https://github.com/tumashu/posframe")
